<?php
// Copyright 1999-2023. Plesk International GmbH. All rights reserved.

declare(strict_types=1);

exit(); // THIS LINE HAS TO BE REMOVED IN PRODUCTION

use WHMCS\Module\Server\SolusVm2Vps\ClientAPI\Response;
use WHMCS\Module\Server\SolusVm2Vps\Database\Models\Hosting;

require("../../../init.php");
header("Content-Type: application/json");

new class() {
    use Response;

    /**
     * The list of secrets to access this script.
     * You can specify more than one - $securitySecrets = [
     *  "3c53d77968815cb51f05c5d67974dd5ad54295d1b5953db167129352c0b0359a"
     *  "3c53d77968815cb51f05c5d67974dd5ad54295d1b5953db167129352c0b03591"
     * ];
     */
    private $securitySecrets = [];

    /**
     * The list of ip addresses of your SolusVM master.
     * You can specify more than one - $connectionIPs = ["127.0.0.1", "10.0.0.1"];
     */
    private $connectionIPs = [];

    public function __construct()
    {
        $_POST = json_decode(file_get_contents('php://input'), true);

        $secret = $_POST["secret"] ?? "";
        $hostname = $_POST["serverHostname"] ?? "";
        $ips = $_POST["serverIps"] ?? [];
        $userId = $_POST["billingUserId"] ?? 0;
        $remoteAddr = $_SERVER["REMOTE_ADDR"] ?? "";

        if (!in_array($remoteAddr, $this->connectionIPs)) {
            $this->error("invalid ip: $remoteAddr", 403);
        }

        if (!in_array($secret, $this->securitySecrets)) {
            $this->error("invalid secret: $secret", 401);
        }

        if (!$hostname) {
            $this->error("serverHostname is required", 400);
        }

        if (!$userId) {
            $this->error("billingUserId is required", 400);
        }

        if (!count($ips)) {
            $this->error("Server has to have at least one IP address", 400);
        }

        $servers = Hosting::getByUserAndHostname($hostname, $userId);
        if (!count($servers)) {
            $this->error("User $userId does not have server with hostname $hostname", 400);
        }
        if (count($servers) > 1) {
            $this->error("User $userId have more than one server with hostname $hostname", 400);
        }

        Hosting::updateByServiceId($servers[0]->id, [
            'dedicatedip' => $ips[0],
            'assignedips' => implode(',', $ips),
        ]);

        $this->success(['message' => "Server $hostname was updated"]);
    }
};