<?php
// Copyright 1999-2023. Plesk International GmbH. All rights reserved.

use WHMCS\Module\Server\SolusVm2Vps\Logger\Logger;
use WHMCS\Module\Server\SolusVm2Vps\SolusAPI\Connector;
use WHMCS\Module\Server\SolusVm2Vps\SolusAPI\Resources\ServerResource;
use WHMCS\Module\Server\SolusVm2Vps\SolusAPI\Resources\UserResource;
use WHMCS\Module\Server\SolusVm2Vps\WhmcsAPI\ClientArea;
use WHMCS\Module\Server\SolusVm2Vps\WhmcsAPI\Config;
use WHMCS\Module\Server\SolusVm2Vps\WhmcsAPI\Product;
use WHMCS\Module\Server\SolusVm2Vps\WhmcsAPI\Servers;
use WHMCS\User\Client;

function solusvm2vpsCreateAddHook() {
    return function (array $params) {
        Product::upgrade($params['upgradeid']);
    };
}

function solusvm2vpsCreatePreDeleteClientHook() {
    return function (array $params) {
        try {
            $config = Config::loadModuleConfig();

            if (empty($config['delete_solus_user'])) {
                return;
            }

            $whmcsUser = Client::findOrFail($params['userid']);
            $serverParams = Servers::getValidParams();

            if (empty($serverParams)) {
                throw new Exception('No valid WHMCS server found');
            }

            $userResource = new UserResource(Connector::create($serverParams));
            $solusUser = $userResource->getUserByEmail($whmcsUser['email']);

            if (empty($solusUser)) {
                return;
            }

            $serverResource = new ServerResource(Connector::create($serverParams));
            $servers = $serverResource->getAllByUser($solusUser['id']);

            if (!empty($servers)) {
                return;
            }

            $userResource->deleteUser($solusUser['id']);
        } catch (Exception $e) {
            Logger::log([], $e->getMessage());
        }
    };
}

function solusvm2vpsCreateClientDetailsValidationHook()
{
    return function (array $params) {
        try {
            $userId = null;

            if (empty($params['email'])) {
                return [];
            }

            // If updating user via admin area
            if (isset($params['userid'])) {
                $userId = $params['userid'];
            }

            // If updating user via client area
            if (array_key_exists('save', $params)) {
                $userId = (new ClientArea())->getUserID();
            }

            if ($userId) {
                $whmcsUser = Client::findOrFail($userId);

                if ($whmcsUser->email === $params['email']) {
                    return [];
                }
            }

            $serverParams = Servers::getValidParams();

            if (empty($serverParams)) {
                return [];
            }

            $userResource = new UserResource(Connector::create($serverParams));
            $solusUser = $userResource->getUserByEmail($params['email']);

            if (!empty($solusUser)) {
                return 'email is already taken';
            }
        } catch (Exception $e) {
            Logger::log([], $e->getMessage());
        }

        return [];
    };
}

function solusvm2vpsCreateClientEditHook()
{
    return function (array $params) {
        try {
            if (empty($params['email'])) {
                return;
            }

            $serverParams = Servers::getValidParams();

            if (empty($serverParams)) {
                return;
            }

            $userResource = new UserResource(Connector::create($serverParams));
            $solusUser = $userResource->getUserByEmail($params['olddata']['email']);

            if (empty($solusUser)) {
                return;
            }

            $userResource->patchUser($solusUser['id'], ['email' => $params['email']]);
        } catch (Exception $e) {
            Logger::log([], $e->getMessage());
        }
    };
}

add_hook('AfterProductUpgrade', 1, solusvm2vpsCreateAddHook());
add_hook('PreDeleteClient', 1, solusvm2vpsCreatePreDeleteClientHook());
add_hook('ClientDetailsValidation', 1, solusvm2vpsCreateClientDetailsValidationHook());
add_hook('ClientEdit', 1, solusvm2vpsCreateClientEditHook());
