<?php
// Copyright 1999-2023. Plesk International GmbH. All rights reserved.

namespace WHMCS\Module\Server\SolusVm2Vps\Database\Models;

use LogicException;
use WHMCS\Database\Capsule as DB;
use WHMCS\Module\Server\SolusVm2Vps\Helpers\Arr;

/**
 * @package WHMCS\Module\Server\SolusVm2Vps\Database\Models
 */
class Hosting
{
    const TABLE = 'tblhosting';

    const STATUS_PENDING = 'Pending';

    /**
     * @param int $id
     * @return mixed
     */
    public static function getByServiceId(int $id)
    {
        return DB::table(self::TABLE)->where(['id' => $id])->first();
    }

    /**
     * @param int $id
     * @param array $data
     * @return void
     */
    public static function updateByServiceId(int $id, array $data): void
    {
        DB::table(self::TABLE)->where('id', $id)->update($data);
    }

    public static function getByUserAndHostname(string $hostname, int $userId)
    {
        return DB::table(self::TABLE)->where([
            'domain' => $hostname,
            'userid' => $userId,
        ])->get();
    }

    public static function updateByUserAndHostname(string $hostname, int $userId, array $data): void
    {
        DB::table(self::TABLE)->where([
            'domain' => $hostname,
            'userid' => $userId,
        ])->update($data);
    }

    public static function syncWithSolusServer(int $serviceId, array $data, bool $updateDomain): void
    {
        $assignedIps = array_column(Arr::get($data, 'ip_addresses.ipv4', []), 'ip');

        $ipv6Addresses = Arr::get($data, 'ip_addresses.ipv6', []);
        if ($ipv6Addresses !== null) {
            // Keeping backwards-compatible with older SolusVM versions with only one IPv6 address
            $ipv6Addresses = array_key_exists('primary_ip', $ipv6Addresses) ? [$ipv6Addresses] : $ipv6Addresses;
            $assignedIps = array_merge($assignedIps, array_column($ipv6Addresses, 'primary_ip'));
        }

        if (count($assignedIps) === 0) {
            throw new LogicException('Virtual server should have at least one ip address');
        }

        $updateData = [
            'dedicatedip' => $assignedIps[0],
            'assignedips' => implode(',', $assignedIps),
        ];
        if ($updateDomain) {
            $updateData['domain'] = $data['name'];
        }

        self::updateByServiceId($serviceId, $updateData);
    }

    public static function getByProductID(int $productID)
    {
        return DB::table(self::TABLE)->where(['packageid' => $productID])->get();
    }

    public static function updateByPackage(int $id, array $data): void
    {
        DB::table(self::TABLE)->where('packageid', $id)->update($data);
    }
}
