<?php
// Copyright 1999-2023. Plesk International GmbH. All rights reserved.

namespace WHMCS\Module\Server\SolusVm2Vps\SolusAPI;

use \GuzzleHttp\Client;
use \GuzzleHttp\ClientInterface;
use WHMCS\Module\Server\SolusVm2Vps\Helpers\Arr;

/**
 * Class Connector
 * @package WHMCS\Module\Server\SolusVm2Vps\SolusAPI
 */
class Connector
{
    /**
     * @param array $params
     * @param string $apiToken
     * @return ClientInterface
     */
    public static function create(array $params, string $apiToken = null): ClientInterface
    {
        $scheme = Arr::get($params, 'serverhttpprefix');
        $host = Arr::get($params, 'serverhostname');

        if ($apiToken === null) {
            $apiToken = Arr::get($params, 'serverpassword');
        }

        if (!$scheme || !$host || !$apiToken) {
            throw new \Exception('Failed to receive server credentials');
        }

        $apiUrl = $scheme . '://' . $host . '/api/v1/';

        return new Client([
            'base_uri' => $apiUrl,
            'base_url' => $apiUrl,
            'defaults' => [
                'headers' => [
                    'Content-Type' => 'application/json',
                    'Accept' => 'application/json',
                    'Authorization' => 'Bearer ' . $apiToken,
                ],
                'verify' => false,
            ],
            'headers' => [
                'Content-Type' => 'application/json',
                'Accept' => 'application/json',
                'Authorization' => 'Bearer ' . $apiToken,
            ],
            'verify' => false,
            'allow_redirects' => [
                'strict'=>true,
            ],
        ]);
    }
}
