<?php
// Copyright 1999-2023. Plesk International GmbH. All rights reserved.

namespace WHMCS\Module\Server\SolusVm2Vps\SolusAPI\Requests;

use WHMCS\Module\Server\SolusVm2Vps\Database\Models\ProductConfigOption;
use WHMCS\Module\Server\SolusVm2Vps\Helpers\Arr;

class ServerResizeRequestBuilder
{
    /**
     * @var int
     */
    private $planId;

    /**
     * @var ?array
     */
    private $customPlanData;

    /**
     * @var bool
     */
    private $isBackupsEnabled;

    private function __construct(int $planId)
    {
        $this->planId = $planId;
    }

    public static function fromWHMCSUpgradeDowngradeParams(array $params): self
    {
        $planId = (int)Arr::get($params, 'configoption1');
        $builder = new self($planId);

        $customPlanData = CustomPlanData::fromModuleParams($params);
        if ($customPlanData) {
            $builder->withCustomPlan($customPlanData);
        }

        $isBackupsEnabled = ConfigOptionExtractor::extractFromModuleParams($params, ProductConfigOption::IS_BACKUPS_ENABLED);
        if ($isBackupsEnabled !== null) {
            $builder->withBackups((bool)$isBackupsEnabled);
        }

        return $builder;
    }

    public function get(): array
    {
        $request = [
            'plan_id' => $this->planId,
            'preserve_disk' => !isset($this->customPlanData['params']['disk']),
        ];

        if ($this->customPlanData) {
            $request['custom_plan'] = $this->customPlanData;
        }

        $request['backup_settings'] = [
            'enabled' => (bool)$this->isBackupsEnabled,
            'schedule' => [
                'type' => 'daily',
                'time' => [
                    'hour' => 0,
                    'minutes' => 0,
                ],
            ],
        ];

        return $request;
    }

    public function withCustomPlan(array $customPlanData): self
    {
        $this->customPlanData = $customPlanData;

        return $this;
    }

    public function withBackups(bool $isBackupsEnabled): self
    {
        $this->isBackupsEnabled = $isBackupsEnabled;

        return $this;
    }
}
