<?php
// Copyright 1999-2023. Plesk International GmbH. All rights reserved.

namespace WHMCS\Module\Server\SolusVm2Vps\WhmcsAPI;

use WHMCS\Module\Server\SolusVm2Vps\Database\Models\Hosting;
use WHMCS\Module\Server\SolusVm2Vps\Database\Models\Product as ProductModel;
use WHMCS\Module\Server\SolusVm2Vps\Database\Models\Server;
use WHMCS\Module\Server\SolusVm2Vps\Database\Models\SolusServer;
use WHMCS\Module\Server\SolusVm2Vps\Database\Models\Upgrade;
use WHMCS\Module\Server\SolusVm2Vps\SolusAPI\Connector;
use WHMCS\Module\Server\SolusVm2Vps\SolusAPI\Resources\ServerResource;

/**
 * @package WHMCS\Module\Server\SolusVm2Vps\WhmcsAPI
 */
class Product
{
    public const MODULE_NAME = 'solusvm2vps';
    public const PACKAGE_OPTIONS_TYPE = 'package';
    public const BACKUP_ENABLED_IN_PRODUCT = 'on';

    public static function updateDomain(int $serviceId, string $domain): void
    {
        localAPI('UpdateClientProduct', [
            'serviceid' => $serviceId,
            'domain' => $domain,
        ]);
    }

    public static function upgrade(int $upgradeId): void
    {
        $upgrade = Upgrade::getById($upgradeId);
        $serviceId = (int) $upgrade->relid;

        if ($upgrade->type !== self::PACKAGE_OPTIONS_TYPE) {
            return;
        }
        list($newProductId, $paymentType) = explode(',', $upgrade->newvalue);

        $newProduct = ProductModel::getById($newProductId);

        if (empty($newProduct) || $newProduct->servertype !== self::MODULE_NAME) {
            return;
        }
        $newPlanId = (int) $newProduct->configoption1;
        $hosting = Hosting::getByServiceId($serviceId);
        $server = SolusServer::getByServiceId($serviceId);
        $serverId = (int) $hosting->server;
        $serverParams = Server::getParams($serverId);

        $request = [
            'plan_id' => $newPlanId,
            'preserve_disk' => false,
            'backup_settings' => [
                'enabled' => $newProduct->configoption6 === self::BACKUP_ENABLED_IN_PRODUCT,
                'schedule' => [
                    'type' => 'daily',
                    'time' => [
                        'hour' => 0,
                        'minutes' => 0,
                    ],
                ],
            ],
        ];

        $serverResource = new ServerResource(Connector::create($serverParams));
        $serverResource->resize($server->server_id, $request);
    }
}
